@@ -14,7 +14,7 @@ use File::Basename;
 use base 'Class::Accessor::Fast';
 
 use vars '$VERSION';
-$VERSION = 0.41;
+$VERSION = '0.50';
 
 __PACKAGE__->mk_accessors( qw( config messages rootset
                                start_time last_time tt ) );
@@ -375,6 +375,16 @@ sub init_tt {
 
 =cut
 
+sub nthpage {
+    my $self = shift;
+    my $n    = shift;
+    my $page = shift;
+    return $page if $n == 1;
+    --$n;
+    $page =~ s/\./_$n./;
+    return $page;
+}
+
 sub generate_pages {
     my $self = shift;
     my $template = shift;
@@ -387,17 +397,11 @@ sub generate_pages {
             $template,
             { @_,
               mariachi  => $self,
+              spool     => $spool,
               # callbacktastic
+              nthpage   => sub { $self->nthpage( shift, $spool ) },
               again     => sub { $again },
               file      => sub { $file  },
-              nthpage   => sub {
-                  my $n    = shift;
-                  my $page = $spool;
-                  return $page if $n == 1;
-                  --$n;
-                  $page =~ s/\./_$n./;
-                  return $page;
-              },
               set_again => sub { $again = shift; return },
               set_file  => sub { $file  = shift; return }, },
             $self->config->output . "/$$.tmp" )
@@ -417,6 +421,8 @@ sub generate_pages {
 sub generate_lurker {
     my $self = shift;
 
+    return unless $self->config->lurker;
+
     my $l = Mariachi::Lurker->new;
     $self->generate_pages(
         'lurker.tt2', 'lurker.html',
@@ -428,7 +434,7 @@ sub generate_lurker {
 }
 
 
-=head2 ->generate_thread_index
+=head2 ->generate_thread
 
 =cut
 
